#[repr(transparent)]pub struct CpuCtrl(pub u32);Expand description
PGC CPU Control Register
Tuple Fields
0: u32Implementations
Sourceimpl CpuCtrl
impl CpuCtrl
Sourcepub const fn pcr(&self) -> CpuCtrlPcr
pub const fn pcr(&self) -> CpuCtrlPcr
Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up
Sourcepub const fn set_pcr(&mut self, val: CpuCtrlPcr)
pub const fn set_pcr(&mut self, val: CpuCtrlPcr)
Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up