#[repr(transparent)]pub struct MegaCtrl(pub u32);Expand description
PGC Mega Control Register
Tuple Fields
0: u32Implementations
Sourceimpl MegaCtrl
impl MegaCtrl
Sourcepub const fn pcr(&self) -> MegaCtrlPcr
pub const fn pcr(&self) -> MegaCtrlPcr
Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up
Sourcepub const fn set_pcr(&mut self, val: MegaCtrlPcr)
pub const fn set_pcr(&mut self, val: MegaCtrlPcr)
Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up